@@ -261,6 +261,13 @@ runtsir <- function(data, xreg = 'cumcases',
 
   }
 
+  ## warning meassure if reporting is very small
+
+  if(any(1/adj.rho < 0.01)){
+    warning('Reporting rate has fallen below 1% -- try lowering the value of sigmamax (default is 3) if you are using
+            regtype="gaussian"')
+  }
+
   ## warning message if reporting > 100%
 
   if(length(which(adj.rho < 1 )) > 1){
@@ -325,7 +332,7 @@ runtsir <- function(data, xreg = 'cumcases',
 
   ## declare the limits to profile S on
 
-  minSmean <- max(0.01*pop,-(min(Z)+1))
+  minSmean <- max(0.01*pop,-(min(Z) - 1))
   Smean <- seq(minSmean, 0.4*mean(pop), length=250)
 
   loglik <- rep(NA, length(Smean))
@@ -506,6 +513,10 @@ runtsir <- function(data, xreg = 'cumcases',
 
   IC <- c(S_start,I_start)
 
+  if(any(IC < 0 )){
+    warning('One (or both) initial condition is zero, try fixing or increasing sbar')
+  }
+
   ## print estimates so far
   ## now we forward simulate the model
 
@@ -536,13 +547,13 @@ runtsir <- function(data, xreg = 'cumcases',
     for (t in 2:(nrow(data))){
 
       if(pred == 'step-ahead'){
-        I[t] <- adj.rho[t]*data$cases[t]
+        lambda <- min(S[t-1],unname(beta[period[t-1]] * S[t-1] * (adj.rho[t-1]*data$cases[t-1])^alpha))
       }
       if(pred == 'forward'){
         I <- I
+        lambda <- min(S[t-1],unname(beta[period[t-1]] * S[t-1] * (I[t-1])^alpha))
       }
 
-      lambda <- min(S[t-1],unname(beta[period[t-1]] * S[t-1] * (I[t-1])^alpha))
 
       #if(lambda < 1 || is.nan(lambda) == T){lambda <- 0}
       if(is.nan(lambda) == T){lambda <- 0}
